@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::GitHub::Meta;
 {
-  $Dist::Zilla::Plugin::GitHub::Meta::VERSION = '0.13';
+  $Dist::Zilla::Plugin::GitHub::Meta::VERSION = '0.14';
 }
 
 use Moose;
@@ -43,7 +43,7 @@ Dist::Zilla::Plugin::GitHub::Meta - Add GitHub repo info to META.{yml,json}
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -70,7 +70,8 @@ It currently sets the following fields:
 =item * C<homepage>
 
 The official home of this project on the web, taken from the GitHub repository
-info. If the C<homepage> option is set to '0' this will be skipped.
+info. If the C<homepage> option is set to false this will be skipped (default is
+true).
 
 =item * C<repository>
 
@@ -97,7 +98,8 @@ This is set to C<git> by default.
 =item * C<web>
 
 URL pointing to the GitHub issues page of the project. If the C<bugs> option is
-set to '0' or the issues are disabled in the GitHub repository, this will be skipped.
+set to false (default is true) or the issues are disabled in the GitHub
+repository, this will be skipped.
 
 =back
 
@@ -124,14 +126,14 @@ sub metadata {
 	my $response	= $http -> request('GET', $url);
 
 	my $json_text = check_response($self, $response);
-	return unless ($json_text ne "");
+	return if not $json_text;
 
 	if ($json_text -> {'repository'} -> {'fork'} == JSON::true() && $self -> fork == 1) {
 		my $url		= $self -> api."/repos/show/".$json_text -> {'repository'} -> {'parent'};
 		my $response	= $http -> request('GET', $url);
 
 		$json_text = check_response($self, $response);
-		return unless ($json_text ne "");
+		return if not $json_text;
 	}
 
 	my ($git_web, $git_url, $homepage, $bugtracker, $wiki);
@@ -200,26 +202,26 @@ is used.
 
 =item C<homepage>
 
-If set to '1' (default), the META homepage field will be set to the
-value of the homepage field set on the GitHub repository's info.
+The META homepage field will be set to the value of the homepage field set on
+the GitHub repository's info if this option is set to true (default).
 
 =item C<wiki>
 
-If set to '1' (default '0'), the META homepage field will be set to the
-URL of the wiki of the GitHub repository, if happens to be activated (see the
-GitHub repository's C<Admin> panel).
+The META homepage field will be set to the URL of the wiki of the GitHub
+repository, if this option is set to true (default is false) and if the GitHub
+Wiki happens to be activated (see the GitHub repository's C<Admin> panel).
 
 =item C<bugs>
 
-If set to '1' (default), the META bugtracker web field will be set to the
-issue's page of the repository on GitHub, if happens to be activated (see the
-GitHub repository's C<Admin> panel).
+The META bugtracker web field will be set to the issue's page of the repository
+on GitHub, if this options is set to true (default) and if the GitHub Issues happen to
+be activated (see the GitHub repository's C<Admin> panel).
 
 =item C<fork>
 
-If set to '1' (default), and if the repository is a GitHub fork of another
-repository, this option will make all the information be taken from the original
-repository instead of the forked one.
+If the repository is a GitHub fork of another repository this option will make
+all the information be taken from the original repository instead of the forked
+one, if it's set to true (default).
 
 =back
 
